@@ -30,7 +30,12 @@ copy('Starfish.pm','tmp/Text/Starfish.pm');
 }
 
 chdir 'tmp' or die;
-&testcase('01', 'replace');
+
+if (&is_module_available('CGI')) {
+  &testcase('01', 'replace'); # "ok 2" requires CGI module
+} else {
+  ok(1); print "\tskipped (ok 2) - CGI module not available\n"; }
+
 &testcase('02', 'replace');
 &testcase('03', 'replace');
 &testcase('05', 'replace');
@@ -278,6 +283,11 @@ sub comparefiles {
   ok(0);
 }
 
+sub is_module_available {
+  my $module = shift; eval qq{require $module};
+  return '' if $@; return 1;
+}
+
 sub getfile($) {
     my $f = shift;
     local *F;
